# -*- coding: utf-8 -*-

from plone.app.contenttypes.testing import PLONE_APP_CONTENTTYPES_FIXTURE
from plone.app.robotframework.testing import REMOTE_LIBRARY_BUNDLE_FIXTURE
from plone.app.testing import applyProfile
from plone.app.testing import FunctionalTesting
from plone.app.testing import IntegrationTesting
from plone.app.testing import PloneSandboxLayer
from plone.testing import z2

import imio.directory.core


class ImioDirectoryCoreLayer(PloneSandboxLayer):
    defaultBases = (PLONE_APP_CONTENTTYPES_FIXTURE,)

    def setUpZope(self, app, configurationContext):
        # Load any other ZCML that is required for your tests.
        # The z3c.autoinclude feature is disabled in the Plone fixture base
        # layer.
        import plone.app.dexterity

        z2.installProduct(app, "plone.restapi")
        self.loadZCML(package=plone.app.dexterity)
        import plone.restapi

        self.loadZCML(package=plone.restapi)
        self.loadZCML(package=imio.directory.core)
        self.loadZCML(package=imio.directory.core, name="overrides.zcml")

    def setUpPloneSite(self, portal):
        applyProfile(portal, "imio.directory.core:testing")


IMIO_DIRECTORY_CORE_FIXTURE = ImioDirectoryCoreLayer()


IMIO_DIRECTORY_CORE_INTEGRATION_TESTING = IntegrationTesting(
    bases=(IMIO_DIRECTORY_CORE_FIXTURE,),
    name="ImioDirectoryCoreLayer:IntegrationTesting",
)

IMIO_DIRECTORY_CORE_FUNCTIONAL_TESTING = FunctionalTesting(
    bases=(
        IMIO_DIRECTORY_CORE_FIXTURE,
        z2.ZSERVER_FIXTURE,
    ),
    name="ImioDirectoryCoreLayer:FunctionalTesting",
)


IMIO_DIRECTORY_CORE_ACCEPTANCE_TESTING = FunctionalTesting(
    bases=(
        IMIO_DIRECTORY_CORE_FIXTURE,
        REMOTE_LIBRARY_BUNDLE_FIXTURE,
        z2.ZSERVER_FIXTURE,
    ),
    name="ImioDirectoryCoreLayer:AcceptanceTesting",
)



# -*- coding: utf-8 -*-

from imio.smartweb.common.interfaces import ILocalManagerAware
from imio.smartweb.locales import SmartwebMessageFactory as _
from plone import schema
from plone.app.vocabularies.catalog import CatalogSource
from plone.app.z3cform.widget import RelatedItemsFieldWidget
from plone.app.z3cform.widget import SelectFieldWidget
from plone.autoform import directives
from plone.dexterity.content import Container
from plone.supermodel import model
from z3c.relationfield.schema import RelationChoice
from z3c.relationfield.schema import RelationList
from zope.interface import implementer


class IEntity(model.Schema):
    """Marker interface and Dexterity Python Schema for Entity"""

    directives.widget(zip_codes=SelectFieldWidget)
    zip_codes = schema.List(
        title=_("Zip codes and cities"),
        description=_("Choose zip codes for this entity"),
        value_type=schema.Choice(vocabulary="imio.smartweb.vocabulary.Cities"),
    )

    populating_entities = RelationList(
        title=_("Populating entities"),
        description=_(
            "Entities that automatically populates this Entity with their contacts."
        ),
        value_type=RelationChoice(
            title="Items selection",
            source=CatalogSource(),
        ),
        default=[],
        required=False,
    )
    directives.widget(
        "populating_entities",
        RelatedItemsFieldWidget,
        vocabulary="plone.app.vocabularies.Catalog",
        pattern_options={
            "selectableTypes": ["imio.directory.Entity"],
            "favorites": [],
        },
    )


@implementer(IEntity, ILocalManagerAware)
class Entity(Container):
    """Entity content type"""
